module.exports = defineTest({
	description: 'Something',
	options: {
		input: ['main-a.js', 'main-b.js', 'main-c.js']
	}
});
